from __future__ import absolute_import, unicode_literals

from django.conf import settings
from django.core import checks
from django.core.exceptions import ImproperlyConfigured

from .sanitizer import Sanitizer

try:
    from functools import lru_cache
except ImportError:  # pragma: no cover
    # Django versions older than 3.0
    from django.utils.lru_cache import lru_cache


def _get_sanitizer(name="default"):
    sanitizers = getattr(settings, "HTML_SANITIZERS", {})
    if name in sanitizers:
        return Sanitizer(sanitizers[name])
    elif name == "default":
        return Sanitizer()
    raise ImproperlyConfigured(
        "Unknown sanitizer %r, did you define HTML_SANITIZERS[%r] in your"
        " Django settings module?" % (name, name)
    )


get_sanitizer = lru_cache(maxsize=None)(_get_sanitizer)


@checks.register()
def check_configuration(app_configs, **kwargs):
    errors = []
    sanitizers = ["default"] + list(getattr(settings, "HTML_SANITIZERS", {}))
    for name in sorted(set(sanitizers)):
        try:
            _get_sanitizer(name)
        except TypeError as exc:
            errors.append(
                checks.Error(
                    "Invalid sanitizer configuration '%s': %s" % (name, exc),
                    id="html_sanitizer.E001",
                )
            )

    return errors



#!/usr/bin/env python

import os
from setuptools import find_packages, setup


setup(
    name="html-sanitizer",
    version=__import__("html_sanitizer").__version__,
    description="HTML sanitizer",
    long_description=open(os.path.join(os.path.dirname(__file__), "README.rst")).read(),
    author="Matthias Kestenholz",
    author_email="mk@feinheit.ch",
    url="https://github.com/matthiask/html-sanitizer/",
    license="BSD License",
    platforms=["OS Independent"],
    packages=find_packages(),
    include_package_data=True,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: Web Environment",
        "Framework :: Django",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Internet :: WWW/HTTP :: Dynamic Content",
        "Topic :: Software Development",
    ],
    install_requires=("lxml>=3.6.1", "beautifulsoup4"),
    test_suite="html_sanitizer.tests",
)
